@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.86 2004/12/01 16:32:21 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.87 2005/01/03 21:49:30 richb Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -846,8 +846,8 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("Con"),
     N_("Constants [#]"),
     NULL,
-    { GDK_SHIFT_MASK, 0 },   
-    { GDK_numbersign, 0 },   
+    { GDK_SHIFT_MASK, 0,              0 },
+    { GDK_numbersign, GDK_numbersign, 0 },   
     '#',
     M_CON,            
     do_pending,
